@@ -1,7 +1,7 @@
 from requests import get
 from simpler.format import human_seconds, human_bytes
 from sys import stdout
-from time import time
+from time import time, sleep
 from threading import Thread
 from traceback import print_exc
 from urllib.request import urlopen
@@ -63,4 +63,16 @@ class DownloaderPool:
 				continue
 			yield url, self.responses[url]
 			del self.responses[url]
-			request_pending_urls.remove(url)
\ No newline at end of file
+			request_pending_urls.remove(url)
+
+_throttle_last = 0
+def throttle(seconds: float = 1) -> None:
+	''' Sleeps the thread so that the function is called every X seconds. '''
+	global _throttle_last
+	now = time()
+	remaining = _throttle_last + seconds - now
+	if remaining > 0:
+		sleep(remaining)
+		_throttle_last += seconds
+	else:
+		_throttle_last = now
\ No newline at end of file
